pub fn get_nested_value_cloned(
data: &OwnedDataValue,
path: &str,
) -> Option<OwnedDataValue>Expand description
Clone the value at path, returning None if the path is unresolvable.
pub fn get_nested_value_cloned(
data: &OwnedDataValue,
path: &str,
) -> Option<OwnedDataValue>Clone the value at path, returning None if the path is unresolvable.