Module workflow

Module workflow 

Structs

ConnectorRef
One task’s connector reference, located within a workflow.
Rollout
Half-open bucket range [bucket_start, bucket_end) over 0..100, giving this workflow a slice of the traffic on its channel.
Workflow
Workflow represents a collection of tasks that execute sequentially (also known as a Rule in rules-engine terminology).

Enums

WorkflowStatus
Workflow lifecycle status